==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-time/lxqt-admin-time_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>DateTime</name>
    <message>
        <source>Time and date setup</source>
        <translation type="vanished">Настройка даты и времени</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>ЧЧ:мм:сс</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Для сохранения изменений необходимы права администратора.&lt;br&gt;Пароль будет запрошен после нажатия на кнопку «Закрыть»&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Настройки даты и времени</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="53"/>
        <source>Date and time</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="62"/>
        <source>Timezone</source>
        <translation>Часовой пояс</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="162"/>
        <source>Authentication Error</source>
        <translation>Ошибка аутентификации</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <source>Timezone setup</source>
        <translation type="vanished">Настройки часового пояса</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Ваш текущий часовой пояс:</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="54"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Для сохранения изменений необходимы права администратора.&lt;br&gt;Пароль будет запрошен после нажатия на кнопку «Закрыть»&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-time/lxqt-admin-time_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>DateTime</name>
    <message>
        <source>Time and date setup</source>
        <translation type="vanished">Настройка даты и времени</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Время:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>ЧЧ:мм:сс</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Дата:</translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Для сохранения изменений необходимы права администратора.&lt;br&gt;Пароль будет запрошен после нажатия на кнопку «Закрыть»&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="42"/>
        <source>Time and date configuration</source>
        <translation>Настройки даты и времени</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="48"/>
        <source>Date and time</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="56"/>
        <source>Timezone</source>
        <translation>Часовой пояс</translation>
    </message>
    <message>
        <location filename="../../../timeadmindialog.cpp" line="117"/>
        <location filename="../../../timeadmindialog.cpp" line="127"/>
        <location filename="../../../timeadmindialog.cpp" line="134"/>
        <location filename="../../../timeadmindialog.cpp" line="144"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication Error</source>
        <translation type="vanished">Ошибка аутентификации</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <source>Timezone setup</source>
        <translation type="vanished">Настройки часового пояса</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>Ваш текущий часовой пояс:</translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="26"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../timezone.ui" line="35"/>
        <source>Filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving changes requires admin permissions.&lt;br&gt;You will be requested after clicking close button&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Для сохранения изменений необходимы права администратора.&lt;br&gt;Пароль будет запрошен после нажатия на кнопку «Закрыть»&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="vanished">Нет</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../../../timezone.cpp" line="42"/>
        <source>None</source>
        <translation type="unfinished">Нет</translation>
    </message>
</context>
</TS>
